/*
 * Project name:
     Force click
 * Copyright:
     (c) Mikroelektronika, 2016.
 * Revision History:
     20160523:
       - initial release (AM);
 * Description:
      Example is written to show you how you can use the Force click.
      Pressing the Flex surface you are changing the resistance of the click
      ADC results is displayed on the LCD.
 * Test configuration:
     MCU:             PIC18F45K22
                      http://ww1.microchip.com/downloads/en/DeviceDoc/41412D.pdf
     Dev.board:       EasyPIC7
                      http://www.mikroe.com/easypic/
     Oscillator:      HS-PLL 32.0000 MHz, 8.0000 MHz Crystal
     Ext. Modules:    LCD display , Force click
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
 * NOTES:
     - Turn on Lcd backlight switch SW4.6. (board specific)
     - Place the Force click to the mikroBUS 1

 */

// Lcd module connections
 sbit LCD_RS at LATB4_bit;
 sbit LCD_EN at LATB5_bit;
 sbit LCD_D4 at LATB0_bit;
 sbit LCD_D5 at LATB1_bit;
 sbit LCD_D6 at LATB2_bit;
 sbit LCD_D7 at LATB3_bit;

 sbit LCD_RS_Direction at TRISB4_bit;
 sbit LCD_EN_Direction at TRISB5_bit;
 sbit LCD_D4_Direction at TRISB0_bit;
 sbit LCD_D5_Direction at TRISB1_bit;
 sbit LCD_D6_Direction at TRISB2_bit;
 sbit LCD_D7_Direction at TRISB3_bit;
// End Lcd module connections


// Declare Variables
 char txt1[] = "Force Click Demo";
 char txt2[] = "Value:        V";
 char txt[6] = {0};
 unsigned int adc_rd;

 const double Vadc_5  = 4.8828125;         // ADC step 5V/1024 4,88mV (10bit ADC)
 const double Vadc_33 = 3.2226562;         // ADC step 3,3V/1024 3,22mV (10bit ADC)


void main() {
  ANSELA = 0x04;                           // Configure RA2 pin as analog
  ANSELB = 0;                              // Configure PORTB pins as digital

  TRISA = 0x04;                            // Set RA2 pin as input
  TRISB = 0x00;

  Lcd_Init();                              // Initialize Lcd
  ADC_Init();                              // Initialize ADC module with default settings

  Lcd_Cmd(_LCD_CLEAR);                     // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);                // Cursor off
  
  Lcd_Out(1,1,txt1);                       // Write text in first row
  Lcd_Out(2,1,txt2);                       // Write text in second row
  
  Delay_ms(1000);                          // Small delay
   
  while (1) {
  
    adc_rd = ADC_Get_Sample(2);            // get ADC value from 2st channel
    Delay_ms(10);
    
    if(adc_rd > 0)
    {
     adc_rd = ((double)adc_rd * Vadc_33);  // volatage input and resolution
                                           // 3.226 = 3300/1023
     FloatToStr(adc_rd, &txt);             // Convert adc reading to text string
     txt[5] = 0;                           // Cut all the numbers after the char 5
    
     Lcd_Out(2,8,txt);                    // Write text in second row
     Delay_ms(200);
    }
    else
    {
     Lcd_Out(2,7,"  0    ");               // Write text in second row
    }
  }
}